==> pyxnat_0.9.0~dev0.orig.tar.gz: pyxnat-0.9.0~dev0/pyxnat/tests/attributes_test.py <==
import os
from uuid import uuid1

from .. import Interface

_modulepath = os.path.dirname(os.path.abspath(__file__))

central = Interface('https://central.xnat.org', 'nosetests', 'nosetests')

sid = uuid1().hex
eid = uuid1().hex

subject = central.select.project('nosetests').subject(sid)
experiment = subject.experiment(eid)

def test_fancy_resource_create():
    field_data = {'experiment':'xnat:mrSessionData',
                  'ID':'TEST_%s' % eid,
                  'xnat:mrSessionData/age':'42',
                  'xnat:subjectData/investigator/lastname':'doe',
                  'xnat:subjectData/investigator/firstname':'john',
                  'xnat:subjectData/ID': 'TEST_%s' % sid,
                  }

    experiment.create(**field_data)

    print subject.id()
    assert subject.exists()
    print experiment.id()
    assert experiment.exists()

    globals()['subject'] = experiment.parent()
    globals()['experiment'] = experiment

def test_attr_get():
    assert experiment.attrs.get('xnat:mrSessionData/age') == '42.0'

def test_attr_mget():
    fields = ['xnat:subjectData/investigator/firstname', 
              'xnat:subjectData/investigator/lastname'
              ]

    assert subject.attrs.mget(fields) == ['john', 'doe']

def test_attr_set():
    experiment.attrs.set('xnat:mrSessionData/age', '26')
    assert experiment.attrs.get('xnat:mrSessionData/age') == '26.0'

def test_attr_mset():
    field_data = {'xnat:subjectData/investigator/firstname':'angus',
                  'xnat:subjectData/investigator/lastname':'young',
                  }

    subject.attrs.mset(field_data)

    assert set(subject.attrs.mget(field_data.keys())) == \
        set(['angus', 'young'])

def test_cleanup():
    subject.delete()
    assert not subject.exists()

==> pyxnat_1.0.1.0.orig.tar.gz: pyxnat-1.0.1.0/pyxnat/tests/attributes_test.py <==
import os
from uuid import uuid1
import time

from .. import Interface

_modulepath = os.path.dirname(os.path.abspath(__file__))

central = Interface(config=os.path.join(os.path.dirname(os.path.abspath(__file__)), 'central.cfg'))

sid = uuid1().hex
eid = uuid1().hex

subject = central.select.project('nosetests').subject(sid)
experiment = subject.experiment(eid)

def test_fancy_resource_create():
    field_data = {'experiment':'xnat:mrSessionData',
                  'ID':'TEST_%s' % eid,
                  'xnat:mrSessionData/age':'42',
                  'xnat:subjectData/investigator/lastname':'doe',
                  'xnat:subjectData/investigator/firstname':'john',
                  'xnat:subjectData/ID': 'TEST_%s' % sid,
                  }

    experiment.create(**field_data)

    assert subject.exists()
    assert experiment.exists()

    globals()['subject'] = experiment.parent()
    globals()['experiment'] = experiment

def test_attr_get():
    assert experiment.attrs.get('xnat:mrSessionData/age') == '42.0'

def test_attr_mget():
    time.sleep(5)
    fields = ['xnat:subjectData/investigator/firstname',
              'xnat:subjectData/investigator/lastname'
              ]

    assert subject.attrs.mget(fields) == ['john', 'doe']

def test_attr_set():
    experiment.attrs.set('xnat:mrSessionData/age', '26')
    assert experiment.attrs.get('xnat:mrSessionData/age') == '26.0'

def test_attr_mset():
    subject = central.select.project('nosetests').subject(sid)
    time.sleep(5)
    field_data = {'xnat:subjectData/investigator/firstname':'angus',
                  'xnat:subjectData/investigator/lastname':'young',
                  }

    subject.attrs.mset(field_data)
    returned = subject.attrs.mget(field_data.keys())

    assert set(returned) == \
        set(field_data.values()), '''set: %s returned: %s ''' %(field_data.values(), returned)

def test_cleanup():
    subject.delete()
    assert not subject.exists()
